Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeBatchConfig ¶
func MakeBatchConfig(conf Config) client.BatchPointsConfig
func MakeFieldKinds ¶
MakeFieldKinds reads the Config and returns a lookup map of tag names to the field type their values should be converted to.
Types ¶
type Config ¶
type Config struct {
// Connection.
Addr null.String `json:"addr" envconfig:"K6_INFLUXDB_ADDR"`
Username null.String `json:"username,omitempty" envconfig:"K6_INFLUXDB_USERNAME"`
Password null.String `json:"password,omitempty" envconfig:"K6_INFLUXDB_PASSWORD"`
Insecure null.Bool `json:"insecure,omitempty" envconfig:"K6_INFLUXDB_INSECURE"`
PayloadSize null.Int `json:"payloadSize,omitempty" envconfig:"K6_INFLUXDB_PAYLOAD_SIZE"`
PushInterval types.NullDuration `json:"pushInterval,omitempty" envconfig:"K6_INFLUXDB_PUSH_INTERVAL"`
ConcurrentWrites null.Int `json:"concurrentWrites,omitempty" envconfig:"K6_INFLUXDB_CONCURRENT_WRITES"`
// Samples.
DB null.String `json:"db" envconfig:"K6_INFLUXDB_DB"`
Precision null.String `json:"precision,omitempty" envconfig:"K6_INFLUXDB_PRECISION"`
Retention null.String `json:"retention,omitempty" envconfig:"K6_INFLUXDB_RETENTION"`
Consistency null.String `json:"consistency,omitempty" envconfig:"K6_INFLUXDB_CONSISTENCY"`
TagsAsFields []string `json:"tagsAsFields,omitempty" envconfig:"K6_INFLUXDB_TAGS_AS_FIELDS"`
}
func GetConsolidatedConfig ¶
func GetConsolidatedConfig(jsonRawConf json.RawMessage, env map[string]string, url string) (Config, error)
GetConsolidatedConfig combines {default config values + JSON config + environment vars + URL config values}, and returns the final result.
func NewConfig ¶
func NewConfig() Config
NewConfig creates a new InfluxDB output config with some default values.
func ParseJSON ¶
func ParseJSON(data json.RawMessage) (Config, error)
ParseJSON parses the supplied JSON into a Config.
type Output ¶
type Output struct {
output.SampleBuffer
Client client.Client
Config Config
BatchConf client.BatchPointsConfig
// contains filtered or unexported fields
}
Output is the influxdb Output struct
func (*Output) Description ¶
Description returns a human-readable description of the output.
Click to show internal directories.
Click to hide internal directories.